pub struct DynamicPeerValidationConfig {
pub url: String,
pub interval: Duration,
pub hostname: Option<String>,
pub certificate_file: Option<String>,
pub private_key: Option<String>,
pub hashi_object_id: Option<String>,
}Expand description
DynamicPeerValidationConfig controls what sui-node, sui-bridge, and hashi-server
binaries (each functioning as a node in a Sui-anchored network) we’ll accept
metrics from. Peer membership is determined dynamically via Sui gRPC calls to
a full node — sui validator set and bridge committee are always resolved
from on-chain state, and hashi membership is resolved when hashi_object_id
is set.
Fields
url: Stringurl is the Sui gRPC url we use to obtain valid peers on the blockchain.
interval: Durationhostname: Option<String>if certificate_file and private_key are not provided, we’ll create a self-signed cert using this hostname
certificate_file: Option<String>incoming client connections to this proxy will be presented with this pub key please use an absolute path
private_key: Option<String>private key for tls please use an absolute path
hashi_object_id: Option<String>hashi::hashi::Hashi shared object id. When set, the resolver discovers
hashi committee members from chain and adds them to the allowlist.